@@ -7,7 +7,7 @@ specimens_navbar = NavbarItem(
     label="Specimens",
     title="Specimens",
     fa_icon="fa-solid fa-flask",
-    codename="edc_navbar.nav_lab_section",
+    codename="edc_lab_dashboard.nav_lab_section",
     url_name="requisition_listboard_url",
 )
 
@@ -21,7 +21,7 @@ navbar.append_item(
     NavbarItem(
         name="requisition",
         label="Requisition",
-        codename="edc_navbar.nav_lab_requisition",
+        codename="edc_lab_dashboard.nav_lab_requisition",
         url_name="requisition_listboard_url",
     )
 )
@@ -30,7 +30,7 @@ navbar.append_item(
     NavbarItem(
         name="receive",
         label="Receive",
-        codename="edc_navbar.nav_lab_receive",
+        codename="edc_lab_dashboard.nav_lab_receive",
         url_name="receive_listboard_url",
     )
 )
@@ -39,7 +39,7 @@ navbar.append_item(
     NavbarItem(
         name="process",
         label="Process",
-        codename="edc_navbar.nav_lab_process",
+        codename="edc_lab_dashboard.nav_lab_process",
         url_name="process_listboard_url",
     )
 )
@@ -48,7 +48,7 @@ navbar.append_item(
     NavbarItem(
         name="pack",
         label="Pack",
-        codename="edc_navbar.nav_lab_pack",
+        codename="edc_lab_dashboard.nav_lab_pack",
         url_name="pack_listboard_url",
     )
 )
@@ -57,7 +57,7 @@ navbar.append_item(
     NavbarItem(
         name="manifest",
         label="Manifest",
-        codename="edc_navbar.nav_lab_manifest",
+        codename="edc_lab_dashboard.nav_lab_manifest",
         url_name="manifest_listboard_url",
     )
 )
@@ -66,7 +66,7 @@ navbar.append_item(
     NavbarItem(
         name="aliquot",
         label="Aliquot",
-        codename="edc_navbar.nav_lab_aliquot",
+        codename="edc_lab_dashboard.nav_lab_aliquot",
         url_name="aliquot_listboard_url",
     )
 )
@@ -75,7 +75,7 @@ navbar.append_item(
     NavbarItem(
         name="result",
         label="Result",
-        codename="edc_navbar.nav_lab_result",
+        codename="edc_lab_dashboard.nav_lab_result",
         url_name="result_listboard_url",
     )
 )
@@ -85,7 +85,7 @@ navbar.append_item(
         name="specimens",
         title="Specimens",
         fa_icon="fa-solid fa-flask",
-        codename="edc_navbar.nav_lab_section",
+        codename="edc_lab_dashboard.nav_lab_section",
         url_name="requisition_listboard_url",
         active=True,
     )
