@@ -9,7 +9,7 @@ class BaseBoxItemListboardView(BoxViewMixin, BaseListboardView):
     navbar_selected_item = "pack"
     ordering = ("-position",)
     listboard_model = BoxItem
-    listboard_view_permission_codename = "edc_dashboard.view_lab_box_listboard"
+    listboard_view_permission_codename = "edc_lab_dashboard.view_lab_box_listboard"
 
     def get_queryset_filter_options(self, request, *args, **kwargs):
         return {"box": self.box}
